@@ -1,5 +1,5 @@
 package DateTime::TimeZone::OlsonDB::Observance;
-$DateTime::TimeZone::OlsonDB::Observance::VERSION = '1.75';
+$DateTime::TimeZone::OlsonDB::Observance::VERSION = '1.93';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use DateTime::Duration;
 use DateTime::TimeZone::OlsonDB;
 use DateTime::TimeZone::OlsonDB::Change;
 
-use List::AllUtils qw( any first );
+use List::Util 1.33 qw( any first );
 use Params::Validate qw( validate SCALAR ARRAYREF UNDEF OBJECT );
 
 sub new {
@@ -25,7 +25,26 @@ sub new {
         }
     );
 
-    my $offset_from_utc = DateTime::TimeZone::offset_as_seconds( $p{gmtoff} );
+    my $offset_from_utc;
+
+    if ( $p{gmtoff} =~ /^([\+\-]?\d\d?)$/ ) {
+
+        # From the Olson database's etcetera file:
+        #
+        # We use POSIX-style signs in the Zone names and the output
+        # abbreviations, even though this is the opposite of what many people
+        # expect. POSIX has positive signs west of Greenwich, but many people
+        # expect positive signs east of Greenwich.  For example, TZ='Etc/GMT+4'
+        # uses the abbreviation "GMT+4" and corresponds to 4 hours behind UT
+        # (i.e. west of Greenwich) even though many people would expect it to
+        # mean 4 hours ahead of UT (i.e. east of Greenwich).
+        $offset_from_utc = 3600 * $1 * -1;
+    }
+    else {
+        $offset_from_utc
+            = DateTime::TimeZone::offset_as_seconds( $p{gmtoff} );
+    }
+
     my $offset_from_std
         = DateTime::TimeZone::offset_as_seconds( $p{offset_from_std} );
 
@@ -57,8 +76,8 @@ sub new {
     return $self;
 }
 
-sub offset_from_utc { $_[0]->{offset_from_utc} }
-sub offset_from_std { $_[0]->{offset_from_std} }
+sub offset_from_utc { $_[0]->{offset_from_utc} || 0 }
+sub offset_from_std { $_[0]->{offset_from_std} || 0 }
 sub total_offset    { $_[0]->offset_from_utc + $_[0]->offset_from_std }
 
 sub rules      { @{ $_[0]->{rules} } }
@@ -69,6 +88,16 @@ sub format { $_[0]->{format} }
 sub utc_start_datetime   { $_[0]->{utc_start_datetime} }
 sub local_start_datetime { $_[0]->{local_start_datetime} }
 
+sub formatted_short_name {
+    my $self   = shift;
+    my $letter = shift;
+
+    my $format = $self->format;
+    return $format unless $format =~ /%/;
+
+    return sprintf( $format, $letter );
+}
+
 sub expand_from_rules {
     my $self = shift;
     my $zone = shift;
@@ -131,7 +160,7 @@ sub expand_from_rules {
                 local_start_datetime => $dt + DateTime::Duration->new(
                     seconds => $self->total_offset + $rule->offset_from_std
                 ),
-                short_name => sprintf( $self->{format}, $rule->letter ),
+                short_name => $self->formatted_short_name( $rule->letter ),
                 observance => $self,
                 rule       => $rule,
             );
